<?php

namespace Drupal\field_list_details;

use Drupal\Core\Entity\EntityInterface;
use Drupal\field_ui\FieldConfigListBuilder;

/**
 * Class FieldListDetailsFieldConfigListBuilder
 *
 * @package Drupal\field_list_details
 */
class FieldListDetailsFieldConfigListBuilder extends FieldConfigListBuilder {

  /**
   * {@inheritdoc}
   */
  public function buildRow(EntityInterface $field_config) {
    $row = parent::buildRow($field_config);
    $settings = $field_config->getSettings();
    $details = [];

    if ($field_config->isRequired()) {
      $details[] = ['value' => '-'.$this->t('required').'-'];
    }

    // Date fields
    if (!empty($settings['datetime_type'])) {
      $details[] = [
        'label' => $this->t('Date type'),
        'value' => $settings['datetime_type'],
      ];
    }

    // Entity references
    if ($field_config->getType() == 'entity_reference') {
      $details[] = [
        'label' => $this->t('Reference'),
        'value' => $settings['target_type'] . (!empty($settings['handler_settings']['target_bundles']) ? ' - '. implode(',', $settings['handler_settings']['target_bundles']) : ''),
      ];;
    }

    // Files & Images
    if ($field_config->getType() == 'file' || $field_config->getType() == 'image') {
      $ffp = $field_config->getThirdPartySettings('filefield_paths');
      $path = "{$settings['file_directory']}";

      if (!empty($ffp)) {
        if ($ffp['enabled']) {
          $path = "{$ffp['file_path']['value']}/{$ffp['file_name']['value']}";

          if ($ffp['active_updating']) {
            $details[] = ['value' => '-active updating-'];
          }
        }
      }

      $details[] = [
        'label' => $this->t('File'),
        'value' => "{$settings['uri_scheme']}://{$path}",
      ];
    }

    if (!empty($details)) {
      $row['data']['label'] = [
        'data' => [
          '#theme' => 'field_list_details_list',
          '#label' => $field_config->label(),
          '#details' => $details,
          '#attributes' => [
            'class' => [ 'field-list-details-list' ]
          ],
        ]
      ];
    }

    return $row;
  }
}
